@@ -17,7 +17,7 @@
 # under the License.
 #
 
-#require 5.6.0;
+require 5.6.0;
 use strict;
 use warnings;
 
@@ -29,7 +29,7 @@ use IO::Select;
 
 package Thrift::Socket;
 BEGIN {
-  $Thrift::Socket::VERSION = '0.6.0_02';
+  $Thrift::Socket::VERSION = '0.6.1';
 }
 
 use base('Thrift::Transport');
@@ -277,7 +277,7 @@ sub flush
 #
 package  Thrift::ServerSocket;
 BEGIN {
-  $Thrift::ServerSocket::VERSION = '0.6.0_02';
+  $Thrift::ServerSocket::VERSION = '0.6.1';
 }
 
 use base qw( Thrift::Socket Thrift::ServerTransport );
